class PackagesController < ApplicationController
  protect_with(Component.name, Component.display_name, [RxModule::Authorization.verb("install", "Install", :install)])
  before_action :set_targets
  before_action :set_target, only: :package

  def package
    render json: @model
  end

  def packages
    render json: @models
  end

  def install
    component = RxModuleComponent.create(install_params)
    ComponentInstallJob.perform_later(component)
    render json: component
  end

  private

  def set_targets
    @models = Component.up_to_date_components_info
  end

  def set_target
    @model = @models.find { |m| m[:id] === lookup_params[:id] }
  end

  def install_params
    unwrapped = params.require(:rx_module_package)
    unwrapped.require(:port)
    hub_ip = Component.ensure_self.ip_address
    unwrapped[:module_id] = params.permit(:id)[:id]
    unwrapped[:ip_address] = hub_ip
    unwrapped[:is_updating] = true
    unwrapped.permit(:port, :module_id, :ip_address, :is_updating)
  end

  def lookup_params
    params.permit(:id)
  end

  def applicable_authorization
    return unless authorizations
    @_auth ||= authorizations[:actions].find do |verb|
      if verb[:controller_methods].is_a? Array
        verb[:controller_methods].any? { |method| method.to_s == params["action"].to_s }
      else
        verb[:controller_methods].to_s == params["action"].to_s
      end
    end
  end
end
