import * as React from "react";
import {observer} from "mobx-react-lite";
import {PaddedPaper} from "@rx-suite/ui";
import {Schedule, ShiftModel} from "../../stores/ShiftStore";
import {WeeklyOptions} from "./recurrence_rule/WeeklyOptions";
import {Grid} from "@material-ui/core";
import {DeleteRuleButton} from "./recurrence_rule/DeleteRuleButton";
import {IntervalField} from "./recurrence_rule/IntervalField";
import {EveryField} from "./recurrence_rule/EveryField";
import {StartDateField} from "./recurrence_rule/StartDateField";
import {ShiftLengthField} from "./recurrence_rule/ShiftLengthField";
import {EndDateField} from "./recurrence_rule/EndDateField";
import {MonthlyOptions} from "./recurrence_rule/MonthlyOptions";

export const RecurrenceRule: React.FunctionComponent<{ shift: ShiftModel, schedule: Schedule, scheduleIndex: number, readOnly?: boolean }> = observer(({
                                                                                                                                                           shift,
                                                                                                                                                           schedule,
                                                                                                                                                           scheduleIndex,
                                                                                                                                                           readOnly
                                                                                                                                                       }) => {
    return (
        <PaddedPaper>
            <Grid container spacing={2}>
                <Grid item xs={11}>
                    <Grid container spacing={2} alignItems={'flex-end'}>
                        <Grid item xs>
                            <IntervalField shift={shift} schedule={schedule} scheduleIndex={scheduleIndex}
                                           readOnly={readOnly}/>
                        </Grid>
                        <Grid item xs>
                            <EveryField shift={shift} schedule={schedule} scheduleIndex={scheduleIndex}
                                        readOnly={readOnly}/>
                        </Grid>
                    </Grid>
                    <Grid container spacing={2}>
                        <Grid item xs={3}>
                            <StartDateField shift={shift} schedule={schedule} scheduleIndex={scheduleIndex}
                                            readOnly={readOnly}/>
                        </Grid>
                        <Grid item xs>
                            <ShiftLengthField shift={shift} schedule={schedule} scheduleIndex={scheduleIndex}
                                              readOnly={readOnly}/>
                        </Grid>
                        <Grid item xs={3}>
                            <EndDateField shift={shift} schedule={schedule} scheduleIndex={scheduleIndex}
                                          readOnly={readOnly}/>
                        </Grid>
                    </Grid>
                    {
                        (schedule.recurrence_rule.every === 'week') &&
                        <WeeklyOptions shift={shift} schedule={schedule} scheduleIndex={scheduleIndex}/>
                    }
                    {
                        (schedule.recurrence_rule.every === 'month') &&
                        <MonthlyOptions shift={shift} schedule={schedule} scheduleIndex={scheduleIndex}/>
                    }
                </Grid>
                <Grid item xs>
                    <DeleteRuleButton shift={shift} schedule={schedule} scheduleIndex={scheduleIndex}
                                      readOnly={readOnly}/>
                </Grid>
            </Grid>
        </PaddedPaper>
    );
});