module GemExtensions
  module RxModule
    module Communicator
      module Hub
        def is_hub?
          true
        end

        def reset_password(user_id, token, password, password_confirmation)
          user = User.find(user_id)
          user.reset_password(token, password, password_confirmation)
          user
        end

        def module_info(module_id)
          component = Component.resolve(module_id)
          JSON.parse(component.render_jbuilder_partial).with_indifferent_access
        end

        def list_modules
          Component.all.map do |c|
            JSON.parse(c.to_json).with_indifferent_access
          end
        end

        def login(user_identifier, user_password)
          model = User.get_by_login_id(user_identifier)

          raise "Unauthorized" unless model&.authenticate(user_password)

          {token: model.generate_token}
        end

        def send_password_email(email, module_id = "rx_hub")
          user = User.get_by_email(email)
          return { status: :unprocessable_entity } unless user

          user.send_password_reset_email(module_id)
          { status: :ok }
        end

        def token_user(token)
          user = LoginToken.eager_load(user: {role: {role_permissions: {component_permission: :component}}}).find_by(value: token)&.user
          if user
            Oj.load(user.to_json(
              except: :password_digest,
              include: {
                role: {
                  methods: :permissions
                },
                o_auths: {}
              }
            ), symbol_keys: true)
          elsif Component.find_by(token: token)
            {
              role: {
                permissions: ComponentPermission.module_token_permissions
              }
            }
          end
        end

        def current_user(token)
          token_user(token)
        end

        def picker_users
          User.for_email_picker
        end

        def get_system_settings
          JSON.parse(SystemSetting.instance.to_json).with_indifferent_access
        end

        def get_icon(id)
          component = Component.find(id)
          component.icon_file.download if component.icon_file.attached?
        end
      end
    end
  end
end
