# == Schema Information
#
# Table name: system_settings
#
#  id                    :bigint           not null, primary key
#  customer_type         :string
#  date_format           :string           default("YYYY/MM/DD")
#  date_time_separator   :string           default(" - ")
#  lens_tray_orientation :integer          default(0)
#  time_format           :string           default("HH:mm:ss")
#  created_at            :datetime         not null
#  updated_at            :datetime         not null
#
class SystemSetting < ApplicationRecord
  has_one_attached :customer_logo_file

  class << self
    def instance
      first_or_create!
    end
  end

  def customer_logo_url
    "/api/rx_module/customer_logo"
  end

  def brand_logo_url
    "#{Component.hub_url}/api/system_settings/brand_logo"
  end

  def is_satisloh_customer?
    customer_type&.upcase == "SATISLOH"
  end

  def is_mes_lite_customer?
    customer_type&.upcase == "MESLITE"
  end

  def owner
    if is_satisloh_customer?
      'SATISLOH'
    elsif is_mes_lite_customer?
      'MESLITE'
    else
      'RXUN'
    end
  end

  def to_json(*args)
    render_jbuilder_partial
  rescue
    super(*args)
  end
end
